@@ -31,9 +31,9 @@
 #include "meminfo.h"
 #include "veth.h"
 
-typedef struct {
+struct env_param {
 	envid_t veid;
-	unsigned long ipt_mask;
+	unsigned long long ipt_mask;
 
 	/*
 	 * features_known is the set of features that are present
@@ -44,7 +44,9 @@ typedef struct {
 	 */
 	unsigned long long features_mask;
 	unsigned long long features_known;
-} env_param;
+	char *osrelease;
+};
+typedef struct env_param env_param_t;
 
 typedef struct {
 	list_head_t userpw;
@@ -73,7 +75,7 @@ typedef struct name_param {
 typedef struct vps_res {
 	fs_param fs;		/**< file system parameters. */
 	tmpl_param tmpl;	/**< template parameters. */
-	env_param env;		/**< environment parameters. */
+	env_param_t env;	/**< environment parameters. */
 	net_param net;		/**< network parameters. */
 	cpu_param cpu;		/**< cpu parameters. */
 	dev_param dev;		/**< device parameters. */
@@ -86,6 +88,7 @@ typedef struct vps_res {
 	misc_param misc;
 	name_param name;
 	io_param io;
+	pci_param pci;
 } vps_res;
 
 enum {
@@ -140,8 +143,6 @@ typedef struct vps_param vps_param;
 int vps_setup_res(vps_handler *h, envid_t veid, dist_actions *actions,
 	fs_param *fs, vps_param *param, int vps_state, skipFlags skip,
 	struct mod_action *action);
-int vps_cleanup_res(vps_handler *h, envid_t veid, vps_param *param,
-	int vps_state);
 int setup_resource_management(vps_handler *h, envid_t veid, vps_res *res);
 int need_configure(vps_res *res);
 
