@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2007 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2009, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -24,10 +24,13 @@
 #include <unistd.h>
 #include <linux/capability.h>
 #include <string.h>
+#include <linux/vzcalluser.h>
 
 #include "cap.h"
+#include "res.h"
 #include "vzerror.h"
 #include "logger.h"
+#include "util.h"
 
 #ifndef	CAP_SETVEID
 #define	CAP_SETVEID	29
@@ -97,6 +100,10 @@ static char *cap_names[] = {
 "FS_MASK"		/*	0x1f	*/
 };
 
+/* We can't include sys/capability.h since it conflicts
+ * with linux/capability.h, so we put this prototype here */
+extern int capget(cap_user_header_t header, const cap_user_data_t data);
+
 static inline int capset(cap_user_header_t header, cap_user_data_t data)
 {
 	return syscall(__NR_capset, header, data);
@@ -110,9 +117,9 @@ static inline int capset(cap_user_header_t header, cap_user_data_t data)
  */
 int get_cap_mask(char *name, unsigned long *mask)
 {
-	int i;
+	unsigned int i;
 
-	for (i = 0; i < sizeof(cap_names) / sizeof(*cap_names); i++) {
+	for (i = 0; i < ARRAY_SIZE(cap_names); i++) {
 		if (!strcasecmp(name, cap_names[i])) {
 			cap_raise(*mask, i);
 			return 0;
@@ -130,13 +137,14 @@ int get_cap_mask(char *name, unsigned long *mask)
  */
 void build_cap_str(cap_param *new, cap_param *old, char *buf, int len)
 {
-	int i, r;
+	unsigned int i;
+	int r;
 	char *sp, *ep;
 
 	sp = buf;
 	ep = buf + len;
 	sp += sprintf(sp, "\"");
-	for (i = 0; i < sizeof(cap_names) / sizeof(*cap_names); i++) {
+	for (i = 0; i < ARRAY_SIZE(cap_names); i++) {
 		int op = 0;
 
 		if (CAP_TO_MASK(i) & new->on)
@@ -165,6 +173,7 @@ static int set_cap(envid_t veid, cap_t mask, int pid)
 
 	memset(&header, 0, sizeof(header));
 	header.version = _LINUX_CAPABILITY_VERSION;
+	capget(&header, NULL); /* Get linux capability version from kernel */
 	header.pid = pid;
 
 	memset(&data, 0, sizeof(data));
@@ -184,17 +193,14 @@ static inline cap_t make_cap_mask(cap_t on, cap_t off)
 	return (CAPDEFAULTMASK | on) & ~off;
 }
 
-/** Apply capability mask to VE.
- * @param veid		VE id.
- * @param cap		capability mask.
- * @return		0 on success.
- */
-int vps_set_cap(envid_t veid, cap_param *cap)
+int vps_set_cap(envid_t veid, struct env_param *env, cap_param *cap)
 {
 	cap_t mask;
 
+	if ((env->features_known & env->features_mask) & VE_FEATURE_BRIDGE)
+		cap_raise(cap->on, CAP_NET_ADMIN);
+
 	mask = make_cap_mask(cap->on, cap->off);
 
 	return set_cap(veid, mask, 0);
 }
-
