@@ -255,7 +255,7 @@ PRINT_DQ(diskinodes)
 
 /* Sort functions */
 
-inline int check_empty_param(const void *val1, const void *val2)
+static inline int check_empty_param(const void *val1, const void *val2)
 {
 	if (val1 == NULL && val2 == NULL)
 		return 0;
@@ -266,12 +266,12 @@ inline int check_empty_param(const void *val1, const void *val2)
 	return 2;
 }
 
-int none_sort_fn(const void *val1, const void *val2)
+static int none_sort_fn(const void *val1, const void *val2)
 {
 	return 0;
 }
 
-int laverage_sort_fn(const void *val1, const void *val2)
+static int laverage_sort_fn(const void *val1, const void *val2)
 {
 	const struct Ccpustat *st1 = ((const struct Cveinfo *)val1)->cpustat;
 	const struct Ccpustat *st2 = ((const struct Cveinfo *)val2)->cpustat;
@@ -288,7 +288,7 @@ int laverage_sort_fn(const void *val1, const void *val2)
 	return (st1->la[2] - st2->la[2]) * 100;
 }
 
-int uptime_sort_fn(const void *val1, const void *val2)
+static int uptime_sort_fn(const void *val1, const void *val2)
 {
 	struct Ccpustat *st1 = ((const struct Cveinfo *)val1)->cpustat;
 	struct Ccpustat *st2 = ((const struct Cveinfo *)val2)->cpustat;
@@ -299,7 +299,7 @@ int uptime_sort_fn(const void *val1, const void *val2)
 	return (st2->uptime - st1->uptime);
 }
 
-int id_sort_fn(const void *val1, const void *val2)
+static int id_sort_fn(const void *val1, const void *val2)
 {
 	int ret;
 	ret = (((const struct Cveinfo*)val1)->veid >
@@ -307,7 +307,7 @@ int id_sort_fn(const void *val1, const void *val2)
 	return ret;
 }
 
-int status_sort_fn(const void *val1, const void *val2)
+static int status_sort_fn(const void *val1, const void *val2)
 {
 	int res;
 	res = ((const struct Cveinfo*)val1)->status -
@@ -317,7 +317,7 @@ int status_sort_fn(const void *val1, const void *val2)
 	return res;
 }
 
-int bootorder_sort_fn(const void *val1, const void *val2)
+static int bootorder_sort_fn(const void *val1, const void *val2)
 {
 	int ret;
 	unsigned long *r1 = ((const struct Cveinfo*)val1)->bootorder;
@@ -339,14 +339,14 @@ int bootorder_sort_fn(const void *val1, const void *val2)
 	return (*r1 > *r2);
 }
 
-int ioprio_sort_fn(const void *val1, const void *val2)
+static int ioprio_sort_fn(const void *val1, const void *val2)
 {
 	return ((const struct Cveinfo *)val1)->io.ioprio >
 		((const struct Cveinfo *)val2)->io.ioprio;
 }
 
 #define SORT_STR_FN(name)						\
-int name ## _sort_fn(const void *val1, const void *val2)		\
+static int name ## _sort_fn(const void *val1, const void *val2)		\
 {									\
 	const char *h1 = ((const struct Cveinfo*)val1)->name;		\
 	const char *h2 = ((const struct Cveinfo*)val2)->name;		\
@@ -363,7 +363,7 @@ SORT_STR_FN(ostemplate)
 SORT_STR_FN(ip)
 
 #define SORT_UL_RES(fn, res, name, index)				\
-int fn(const void *val1, const void *val2)				\
+static int fn(const void *val1, const void *val2)			\
 {									\
 	const struct C ## res *r1 = ((const struct Cveinfo *)val1)->res;\
 	const struct C ## res *r2 = ((const struct Cveinfo *)val2)->res;\
@@ -413,7 +413,7 @@ SORT_DQ(diskinodes)
 SORT_UL_RES(cpulimit_sort_fn, cpu, limit, 0)
 SORT_UL_RES(cpuunits_sort_fn, cpu, limit, 1)
 
-struct Cfield field_names[] =
+static struct Cfield field_names[] =
 {
 /* ctid should have index 0 */
 {"ctid", "CTID", "%10s", 0, RES_NONE, print_veid, id_sort_fn},
@@ -531,10 +531,10 @@ struct Cfield field_names[] =
 {"numothersock.f", "NOTHSOCK.F", "%10s", 4, RES_UBC,print_ubc_numothersock, numothersock_f_sort_fn},
 
 {"dcachesize", "DCACHESZ", "%10s", 0, RES_UBC,print_ubc_dcachesize, dcachesize_h_sort_fn},
-{"dcachesize.m", "DCACHESZ.M", "%10s", 1, RES_UBC,print_ubc_dcachesize, dcachesize_h_sort_fn},
-{"dcachesize.b", "DCACHESZ.B", "%10s", 2, RES_UBC,print_ubc_dcachesize, dcachesize_h_sort_fn},
-{"dcachesize.l", "DCACHESZ.L", "%10s", 3, RES_UBC,print_ubc_dcachesize, dcachesize_h_sort_fn},
-{"dcachesize.f", "DCACHESZ.F", "%10s", 4, RES_UBC,print_ubc_dcachesize, dcachesize_h_sort_fn},
+{"dcachesize.m", "DCACHESZ.M", "%10s", 1, RES_UBC,print_ubc_dcachesize, dcachesize_m_sort_fn},
+{"dcachesize.b", "DCACHESZ.B", "%10s", 2, RES_UBC,print_ubc_dcachesize, dcachesize_b_sort_fn},
+{"dcachesize.l", "DCACHESZ.L", "%10s", 3, RES_UBC,print_ubc_dcachesize, dcachesize_l_sort_fn},
+{"dcachesize.f", "DCACHESZ.F", "%10s", 4, RES_UBC,print_ubc_dcachesize, dcachesize_f_sort_fn},
 
 {"numfile", "NFILE", "%10s", 0, RES_UBC,print_ubc_numfile, numfile_h_sort_fn},
 {"numfile.m", "NFILE.M", "%10s", 1, RES_UBC,print_ubc_numfile, numfile_m_sort_fn},
@@ -559,8 +559,8 @@ struct Cfield field_names[] =
 {"diskspace.h", "DSPACE.H", "%10s", 2, RES_QUOTA, print_diskspace, diskspace_h_sort_fn},
 
 {"diskinodes", "DINODES", "%10s", 0, RES_QUOTA, print_diskinodes, diskinodes_u_sort_fn},
-{"diskinodes.s", "DINODES.S", "%10s", 1, RES_QUOTA, print_diskinodes, diskinodes_u_sort_fn},
-{"diskinodes.h", "DINODES.H", "%10s", 2, RES_QUOTA, print_diskinodes, diskinodes_u_sort_fn},
+{"diskinodes.s", "DINODES.S", "%10s", 1, RES_QUOTA, print_diskinodes, diskinodes_s_sort_fn},
+{"diskinodes.h", "DINODES.H", "%10s", 2, RES_QUOTA, print_diskinodes, diskinodes_h_sort_fn},
 
 {"laverage", "LAVERAGE", "%14s", 0, RES_CPUSTAT, print_laverage, laverage_sort_fn},
 {"uptime", "UPTIME", "%15s", 1, RES_CPUSTAT, print_uptime, uptime_sort_fn},
@@ -575,7 +575,7 @@ struct Cfield field_names[] =
 	print_bootorder, bootorder_sort_fn},
 };
 
-void *x_malloc(int size)
+static void *x_malloc(int size)
 {
 	void *p;
 	if ((p = malloc(size)) == NULL) {
@@ -585,7 +585,7 @@ void *x_malloc(int size)
 	return p;
 }
 
-void *x_realloc(void *ptr, int size)
+static void *x_realloc(void *ptr, int size)
 {
 	void *tmp;
 
@@ -596,12 +596,12 @@ void *x_realloc(void *ptr, int size)
 	return tmp;
 }
 
-void usage()
+static void usage()
 {
-	fprintf(stderr, "\n"
-"Usage:	vzlist	[-a|-S] [-n] [-H] [-o field[,field...]] [-s [-]field]\n"
-"		[-h pattern] [-N pattern] [-d pattern] [CTID [CTID ...]|-1]\n"
-"	vzlist -L\n"
+	fprintf(stderr,
+"Usage:	vzlist [-a | -S] [-n] [-H] [-o field[,field...] | -1] [-s [-]field]\n"
+"	       [-h pattern] [-N pattern] [-d pattern] [CTID [CTID ...]]\n"
+"	vzlist -L | --list\n"
 "\n"
 "Options:\n"
 "	-a, --all		list all containers\n"
@@ -609,6 +609,7 @@ void usage()
 "	-n, --name		display containers' names\n"
 "	-H, --no-header		suppress columns header\n"
 "	-o, --output		output only specified fields\n"
+"	-1			synonym for -H -octid\n"
 "	-s, --sort		sort by the specified field\n"
 "				('-field' to reverse sort order)\n"
 "	-h, --hostname		filter CTs by hostname pattern\n"
@@ -618,17 +619,17 @@ void usage()
 	);
 }
 
-int id_search_fn(const void* val1, const void* val2)
+static int id_search_fn(const void* val1, const void* val2)
 {
 	return (*(const int *)val1 - ((const struct Cveinfo*)val2)->veid);
 }
 
-int veid_search_fn(const void* val1, const void* val2)
+static int veid_search_fn(const void* val1, const void* val2)
 {
 	return (*(const int *)val1 - *(const int *)val2);
 }
 
-char* trim_eol_space(char *sp, char *ep)
+static char* trim_eol_space(char *sp, char *ep)
 {
 /*	if (ep == NULL)
 		ep = sp + strlen(sp); */
@@ -639,7 +640,7 @@ char* trim_eol_space(char *sp, char *ep)
 	return sp;
 }
 
-void print_hdr()
+static void print_hdr()
 {
 	struct Cfield_order *p;
 	int f;
@@ -662,7 +663,7 @@ void print_hdr()
 	1 - match
 	0 - do not match
 */
-inline int check_pattern(char *str, char *pat)
+static inline int check_pattern(char *str, char *pat)
 {
 	if (pat == NULL)
 		return 1;
@@ -671,7 +672,7 @@ inline int check_pattern(char *str, char *pat)
 	return !fnmatch(pat, str, 0);
 }
 
-void filter_by_hostname()
+static void filter_by_hostname()
 {
 	int i;
 
@@ -681,7 +682,7 @@ void filter_by_hostname()
 	}
 }
 
-void filter_by_name()
+static void filter_by_name()
 {
 	int i;
 
@@ -691,7 +692,7 @@ void filter_by_name()
 	}
 }
 
-void filter_by_description()
+static void filter_by_description()
 {
 	int i;
 
@@ -701,7 +702,7 @@ void filter_by_description()
 	}
 }
 
-void print_ve()
+static void print_ve()
 {
 	struct Cfield_order *p;
 	int i, f, idx;
@@ -740,7 +741,7 @@ void print_ve()
 	}
 }
 
-void add_elem(struct Cveinfo *ve)
+static void add_elem(struct Cveinfo *ve)
 {
 	veinfo = (struct Cveinfo *)x_realloc(veinfo,
 				sizeof(struct Cveinfo) * ++n_veinfo);
@@ -748,13 +749,13 @@ void add_elem(struct Cveinfo *ve)
 	return;
 }
 
-inline struct Cveinfo *find_ve(int veid)
+static inline struct Cveinfo *find_ve(int veid)
 {
 	return (struct Cveinfo *) bsearch(&veid, veinfo, n_veinfo,
 			sizeof(struct Cveinfo), id_search_fn);
 }
 
-void update_ve(int veid, char *ip, int status)
+static void update_ve(int veid, char *ip, int status)
 {
 	struct Cveinfo *tmp, ve;
 
@@ -777,7 +778,7 @@ void update_ve(int veid, char *ip, int status)
 	return;
 }
 
-void update_ubc(int veid, struct Cubc *ubc)
+static void update_ubc(int veid, struct Cubc *ubc)
 {
 	struct Cveinfo *tmp;
 
@@ -786,7 +787,7 @@ void update_ubc(int veid, struct Cubc *ubc)
 	return ;
 }
 
-void update_quota(int veid, struct Cquota *quota)
+static void update_quota(int veid, struct Cquota *quota)
 {
 	struct Cveinfo *tmp;
 
@@ -797,7 +798,7 @@ void update_quota(int veid, struct Cquota *quota)
 	return;
 }
 
-void update_cpu(int veid, unsigned long limit, unsigned long units)
+static void update_cpu(int veid, unsigned long limit, unsigned long units)
 {
 	struct Cveinfo *tmp;
 	struct Ccpu *cpu;
@@ -811,7 +812,7 @@ void update_cpu(int veid, unsigned long limit, unsigned long units)
 	return;
 }
 
-void update_cpustat(int veid, struct Ccpustat *st)
+static void update_cpustat(int veid, struct Ccpustat *st)
 {
 	struct Cveinfo *tmp;
 
@@ -822,20 +823,6 @@ void update_cpustat(int veid, struct Ccpustat *st)
 	return;
 }
 
-char *parse_var(char *var)
-{
-	char *sp, *ep;
-
-	if (var == NULL)
-		return NULL;
-	sp = var;
-	while (*sp && (*sp == '"' || isspace(*sp))) sp++;
-	ep = var + strlen(var) - 1;
-	while (ep > sp && (*ep == '"' || isspace(*ep))) *ep-- = 0;
-
-	return strdup(sp);
-}
-
 #define MERGE_QUOTA(name, quota, dq)				\
 do {								\
 	if (dq.name != NULL) {					\
@@ -844,7 +831,7 @@ do {								\
 	}							\
 } while(0);
 
-void merge_conf(struct Cveinfo *ve, vps_res *res)
+static void merge_conf(struct Cveinfo *ve, vps_res *res)
 {
 	if (ve->ubc == NULL) {
 		ve->ubc = x_malloc(sizeof(struct Cubc));
@@ -927,7 +914,7 @@ do {								\
 	ve->io.ioprio = res->io.ioprio;
 }
 
-int read_ves_param()
+static int read_ves_param()
 {
 	int i;
 	char buf[128];
@@ -966,7 +953,7 @@ int read_ves_param()
 }
 
 
-int check_veid_restr(int veid)
+static int check_veid_restr(int veid)
 {
 	if (g_ve_list == NULL)
 		return 1;
@@ -985,7 +972,7 @@ do {						\
 	}					\
 } while(0);					\
 
-int get_ub()
+static int get_ub()
 {
 	char buf[256];
 	int veid, prev_veid;
@@ -1072,33 +1059,7 @@ int get_ub()
 	return 0;
 }
 
-char *remove_sp(char *str)
-{
-	char *sp, *ep, *tp;
-	int skip;
-
-	if (str == NULL)
-		return NULL;
-	tp = str;
-	sp = tp;
-	ep = str + strlen(str);
-	skip = 0;
-	while (sp < ep) {
-		*tp = *sp;
-		if (isspace(*sp)) {
-			*tp = ' ';
-			skip++;
-		} else
-			skip = 0;
-		if (skip <= 1)
-			tp++;
-		sp++;
-	}
-	*tp = 0;
-	return strdup(str);
-}
-
-char *invert_ip(char *ips)
+static char *invert_ip(char *ips)
 {
 	char *tmp, *p, *ep, *tp;
 	size_t len;
@@ -1270,7 +1231,7 @@ error:
 }
 #endif
 
-int get_run_quota_stat()
+static int get_run_quota_stat()
 {
 	unsigned long usage, softlimit, hardlimit, time, exp;
 	int veid = 0, prev_veid = 0;
@@ -1316,54 +1277,6 @@ int get_run_quota_stat()
 	return 0;
 }
 
-int get_stop_quota_stat(int veid)
-{
-	char buf[255];
-	char res[16];
-	FILE *fp;
-	unsigned long usage, softlimit, hardlimit;
-	int status;
-	struct Cquota quota;
-
-	snprintf(buf, sizeof(buf), VZQUOTA " show %d 2>/dev/null", veid);
-	if ((fp = popen(buf, "r")) == NULL)
-		return 1;
-	memset(&quota, 0, sizeof(quota));
-	while(!feof(fp)) {
-		if (fgets(buf, sizeof(buf), fp) == NULL)
-			break;
-		if (sscanf(buf, "%15s %lu %lu %lu", res, &usage,
-				&softlimit, &hardlimit) != 4)
-		{
-			continue;
-		}
-		if (!strcmp(res, "1k-blocks")) {
-			quota.diskspace[0] = usage;
-			quota.diskspace[1] = softlimit;
-			quota.diskspace[2] = hardlimit;
-		} else if (!strcmp(res, "inodes")) {
-			quota.diskinodes[0] = usage;
-			quota.diskinodes[1] = softlimit;
-			quota.diskinodes[2] = hardlimit;
-		}
-	}
-	status = pclose(fp);
-	if (WEXITSTATUS(status))
-		return 1;
-	update_quota(veid, &quota);
-	return 0;
-}
-
-int get_stop_quota_stats()
-{
-	int i;
-	for (i = 0; i < n_veinfo; i++) {
-		if (veinfo[i].status == VE_STOPPED && !veinfo[i].hide)
-			get_stop_quota_stat(veinfo[i].veid);
-	}
-	return 0;
-}
-
 static long get_clk_tck()
 {
 	if (__clk_tck != -1)
@@ -1372,7 +1285,7 @@ static long get_clk_tck()
 	return __clk_tck;
 }
 
-int get_ve_cpustat(int veid)
+static int get_ve_cpustat(int veid)
 {
 	struct vz_cpu_stat stat;
 	struct vzctl_cpustatctl statctl;
@@ -1392,7 +1305,7 @@ int get_ve_cpustat(int veid)
 	return 0;
 }
 
-int get_ves_cpustat()
+static int get_ves_cpustat()
 {
 	int i;
 
@@ -1407,7 +1320,7 @@ int get_ves_cpustat()
 	return 0;
 }
 
-int get_mounted_status()
+static int get_mounted_status()
 {
 	int i;
 	char buf[512];
@@ -1432,7 +1345,7 @@ int get_mounted_status()
 	return 0;
 }
 
-int get_ves_cpu()
+static int get_ves_cpu()
 {
 	unsigned long tmp;
 	int veid, id, weight, rate;
@@ -1462,7 +1375,7 @@ int get_ves_cpu()
 	return 0;
 }
 
-int get_ve_list()
+static int get_ve_list()
 {
 	DIR *dp;
 	struct dirent *ep;
@@ -1491,7 +1404,7 @@ int get_ve_list()
 	return 0;
 }
 
-int search_field(char *name)
+static int search_field(char *name)
 {
 	unsigned int i;
 
@@ -1504,7 +1417,7 @@ int search_field(char *name)
 	return -1;
 }
 
-int build_field_order(char *fields)
+static int build_field_order(char *fields)
 {
 	struct Cfield_order *tmp, *prev = NULL;
 	char *sp, *ep, *p;
@@ -1553,7 +1466,7 @@ static inline int check_param(int res_type)
 	return 0;
 }
 
-int collect()
+static int collect()
 {
 	int update = 0;
 	int ret;
@@ -1588,7 +1501,7 @@ int collect()
 	return 0;
 }
 
-void print_names()
+static void print_names()
 {
 	unsigned int i;
 
@@ -1598,7 +1511,7 @@ void print_names()
 	return;
 }
 
-void free_veinfo()
+static void free_veinfo()
 {
 	int i;
 
